@@ -76,7 +76,7 @@ class Platform(Flag):
             else:
                 return "brew install "
         elif platform == cls.UBUNTU:
-            return "brew install "
+            return "sudo apt install "
         else:
             raise cls.NotSupported()
 
